#[non_exhaustive]pub struct BackfillAllStrategy {
pub excluded_objects: Option<ExcludedObjects>,
/* private fields */
}Expand description
Backfill strategy to automatically backfill the Stream’s objects. Specific objects can be excluded.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.excluded_objects: Option<ExcludedObjects>List of objects to exclude.
Implementations
Sourceimpl BackfillAllStrategy
impl BackfillAllStrategy
Sourcepub fn set_excluded_objects<T: Into<Option<ExcludedObjects>>>(
self,
v: T,
) -> Self
pub fn set_excluded_objects<T: Into<Option<ExcludedObjects>>>( self, v: T, ) -> Self
Sets the value of excluded_objects.
Note that all the setters affecting excluded_objects are mutually
exclusive.
Example
use google_cloud_datastream_v1::model::OracleRdbms;
let x = BackfillAllStrategy::new().set_excluded_objects(Some(
google_cloud_datastream_v1::model::stream::backfill_all_strategy::ExcludedObjects::OracleExcludedObjects(OracleRdbms::default().into())));Sourcepub fn oracle_excluded_objects(&self) -> Option<&Box<OracleRdbms>>
pub fn oracle_excluded_objects(&self) -> Option<&Box<OracleRdbms>>
The value of excluded_objects
if it holds a OracleExcludedObjects, None if the field is not set or
holds a different branch.
Sourcepub fn set_oracle_excluded_objects<T: Into<Box<OracleRdbms>>>(
self,
v: T,
) -> Self
pub fn set_oracle_excluded_objects<T: Into<Box<OracleRdbms>>>( self, v: T, ) -> Self
Sets the value of excluded_objects
to hold a OracleExcludedObjects.
Note that all the setters affecting excluded_objects are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::OracleRdbms;
let x = BackfillAllStrategy::new().set_oracle_excluded_objects(OracleRdbms::default()/* use setters */);
assert!(x.oracle_excluded_objects().is_some());
assert!(x.mysql_excluded_objects().is_none());
assert!(x.postgresql_excluded_objects().is_none());
assert!(x.sql_server_excluded_objects().is_none());
assert!(x.salesforce_excluded_objects().is_none());
assert!(x.mongodb_excluded_objects().is_none());Sourcepub fn mysql_excluded_objects(&self) -> Option<&Box<MysqlRdbms>>
pub fn mysql_excluded_objects(&self) -> Option<&Box<MysqlRdbms>>
The value of excluded_objects
if it holds a MysqlExcludedObjects, None if the field is not set or
holds a different branch.
Sourcepub fn set_mysql_excluded_objects<T: Into<Box<MysqlRdbms>>>(self, v: T) -> Self
pub fn set_mysql_excluded_objects<T: Into<Box<MysqlRdbms>>>(self, v: T) -> Self
Sets the value of excluded_objects
to hold a MysqlExcludedObjects.
Note that all the setters affecting excluded_objects are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::MysqlRdbms;
let x = BackfillAllStrategy::new().set_mysql_excluded_objects(MysqlRdbms::default()/* use setters */);
assert!(x.mysql_excluded_objects().is_some());
assert!(x.oracle_excluded_objects().is_none());
assert!(x.postgresql_excluded_objects().is_none());
assert!(x.sql_server_excluded_objects().is_none());
assert!(x.salesforce_excluded_objects().is_none());
assert!(x.mongodb_excluded_objects().is_none());Sourcepub fn postgresql_excluded_objects(&self) -> Option<&Box<PostgresqlRdbms>>
pub fn postgresql_excluded_objects(&self) -> Option<&Box<PostgresqlRdbms>>
The value of excluded_objects
if it holds a PostgresqlExcludedObjects, None if the field is not set or
holds a different branch.
Sourcepub fn set_postgresql_excluded_objects<T: Into<Box<PostgresqlRdbms>>>(
self,
v: T,
) -> Self
pub fn set_postgresql_excluded_objects<T: Into<Box<PostgresqlRdbms>>>( self, v: T, ) -> Self
Sets the value of excluded_objects
to hold a PostgresqlExcludedObjects.
Note that all the setters affecting excluded_objects are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::PostgresqlRdbms;
let x = BackfillAllStrategy::new().set_postgresql_excluded_objects(PostgresqlRdbms::default()/* use setters */);
assert!(x.postgresql_excluded_objects().is_some());
assert!(x.oracle_excluded_objects().is_none());
assert!(x.mysql_excluded_objects().is_none());
assert!(x.sql_server_excluded_objects().is_none());
assert!(x.salesforce_excluded_objects().is_none());
assert!(x.mongodb_excluded_objects().is_none());Sourcepub fn sql_server_excluded_objects(&self) -> Option<&Box<SqlServerRdbms>>
pub fn sql_server_excluded_objects(&self) -> Option<&Box<SqlServerRdbms>>
The value of excluded_objects
if it holds a SqlServerExcludedObjects, None if the field is not set or
holds a different branch.
Sourcepub fn set_sql_server_excluded_objects<T: Into<Box<SqlServerRdbms>>>(
self,
v: T,
) -> Self
pub fn set_sql_server_excluded_objects<T: Into<Box<SqlServerRdbms>>>( self, v: T, ) -> Self
Sets the value of excluded_objects
to hold a SqlServerExcludedObjects.
Note that all the setters affecting excluded_objects are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::SqlServerRdbms;
let x = BackfillAllStrategy::new().set_sql_server_excluded_objects(SqlServerRdbms::default()/* use setters */);
assert!(x.sql_server_excluded_objects().is_some());
assert!(x.oracle_excluded_objects().is_none());
assert!(x.mysql_excluded_objects().is_none());
assert!(x.postgresql_excluded_objects().is_none());
assert!(x.salesforce_excluded_objects().is_none());
assert!(x.mongodb_excluded_objects().is_none());Sourcepub fn salesforce_excluded_objects(&self) -> Option<&Box<SalesforceOrg>>
pub fn salesforce_excluded_objects(&self) -> Option<&Box<SalesforceOrg>>
The value of excluded_objects
if it holds a SalesforceExcludedObjects, None if the field is not set or
holds a different branch.
Sourcepub fn set_salesforce_excluded_objects<T: Into<Box<SalesforceOrg>>>(
self,
v: T,
) -> Self
pub fn set_salesforce_excluded_objects<T: Into<Box<SalesforceOrg>>>( self, v: T, ) -> Self
Sets the value of excluded_objects
to hold a SalesforceExcludedObjects.
Note that all the setters affecting excluded_objects are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::SalesforceOrg;
let x = BackfillAllStrategy::new().set_salesforce_excluded_objects(SalesforceOrg::default()/* use setters */);
assert!(x.salesforce_excluded_objects().is_some());
assert!(x.oracle_excluded_objects().is_none());
assert!(x.mysql_excluded_objects().is_none());
assert!(x.postgresql_excluded_objects().is_none());
assert!(x.sql_server_excluded_objects().is_none());
assert!(x.mongodb_excluded_objects().is_none());Sourcepub fn mongodb_excluded_objects(&self) -> Option<&Box<MongodbCluster>>
pub fn mongodb_excluded_objects(&self) -> Option<&Box<MongodbCluster>>
The value of excluded_objects
if it holds a MongodbExcludedObjects, None if the field is not set or
holds a different branch.
Sourcepub fn set_mongodb_excluded_objects<T: Into<Box<MongodbCluster>>>(
self,
v: T,
) -> Self
pub fn set_mongodb_excluded_objects<T: Into<Box<MongodbCluster>>>( self, v: T, ) -> Self
Sets the value of excluded_objects
to hold a MongodbExcludedObjects.
Note that all the setters affecting excluded_objects are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::MongodbCluster;
let x = BackfillAllStrategy::new().set_mongodb_excluded_objects(MongodbCluster::default()/* use setters */);
assert!(x.mongodb_excluded_objects().is_some());
assert!(x.oracle_excluded_objects().is_none());
assert!(x.mysql_excluded_objects().is_none());
assert!(x.postgresql_excluded_objects().is_none());
assert!(x.sql_server_excluded_objects().is_none());
assert!(x.salesforce_excluded_objects().is_none());Trait Implementations
Sourceimpl Clone for BackfillAllStrategy
impl Clone for BackfillAllStrategy
Sourcefn clone(&self) -> BackfillAllStrategy
fn clone(&self) -> BackfillAllStrategy
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BackfillAllStrategy
impl Debug for BackfillAllStrategy
Sourceimpl Default for BackfillAllStrategy
impl Default for BackfillAllStrategy
Sourcefn default() -> BackfillAllStrategy
fn default() -> BackfillAllStrategy
Sourceimpl Message for BackfillAllStrategy
impl Message for BackfillAllStrategy
Sourceimpl PartialEq for BackfillAllStrategy
impl PartialEq for BackfillAllStrategy
impl StructuralPartialEq for BackfillAllStrategy