#[non_exhaustive]pub struct ConnectionProfile {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub display_name: String,
pub satisfies_pzs: Option<bool>,
pub satisfies_pzi: Option<bool>,
pub profile: Option<Profile>,
pub connectivity: Option<Connectivity>,
/* private fields */
}Expand description
A set of reusable connection configurations to be used as a source or destination for a stream.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. Identifier. The resource’s name.
create_time: Option<Timestamp>Output only. The create time of the resource.
update_time: Option<Timestamp>Output only. The update time of the resource.
labels: HashMap<String, String>Labels.
display_name: StringRequired. Display name.
satisfies_pzs: Option<bool>Output only. Reserved for future use.
satisfies_pzi: Option<bool>Output only. Reserved for future use.
profile: Option<Profile>Connection configuration for the ConnectionProfile.
connectivity: Option<Connectivity>Connectivity options used to establish a connection to the profile.
Implementations
Sourceimpl ConnectionProfile
impl ConnectionProfile
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = ConnectionProfile::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = ConnectionProfile::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = ConnectionProfile::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = ConnectionProfile::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = ConnectionProfile::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = ConnectionProfile::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = ConnectionProfile::new().set_display_name("example");Sourcepub fn set_satisfies_pzs<T>(self, v: T) -> Self
pub fn set_satisfies_pzs<T>(self, v: T) -> Self
Sets the value of satisfies_pzs.
Example
let x = ConnectionProfile::new().set_satisfies_pzs(true);Sourcepub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
Sets or clears the value of satisfies_pzs.
Example
let x = ConnectionProfile::new().set_or_clear_satisfies_pzs(Some(false));
let x = ConnectionProfile::new().set_or_clear_satisfies_pzs(None::<bool>);Sourcepub fn set_satisfies_pzi<T>(self, v: T) -> Self
pub fn set_satisfies_pzi<T>(self, v: T) -> Self
Sets the value of satisfies_pzi.
Example
let x = ConnectionProfile::new().set_satisfies_pzi(true);Sourcepub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
Sets or clears the value of satisfies_pzi.
Example
let x = ConnectionProfile::new().set_or_clear_satisfies_pzi(Some(false));
let x = ConnectionProfile::new().set_or_clear_satisfies_pzi(None::<bool>);Sourcepub fn set_profile<T: Into<Option<Profile>>>(self, v: T) -> Self
pub fn set_profile<T: Into<Option<Profile>>>(self, v: T) -> Self
Sets the value of profile.
Note that all the setters affecting profile are mutually
exclusive.
Example
use google_cloud_datastream_v1::model::OracleProfile;
let x = ConnectionProfile::new().set_profile(Some(
google_cloud_datastream_v1::model::connection_profile::Profile::OracleProfile(OracleProfile::default().into())));Sourcepub fn oracle_profile(&self) -> Option<&Box<OracleProfile>>
pub fn oracle_profile(&self) -> Option<&Box<OracleProfile>>
The value of profile
if it holds a OracleProfile, None if the field is not set or
holds a different branch.
Sourcepub fn set_oracle_profile<T: Into<Box<OracleProfile>>>(self, v: T) -> Self
pub fn set_oracle_profile<T: Into<Box<OracleProfile>>>(self, v: T) -> Self
Sets the value of profile
to hold a OracleProfile.
Note that all the setters affecting profile are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::OracleProfile;
let x = ConnectionProfile::new().set_oracle_profile(OracleProfile::default()/* use setters */);
assert!(x.oracle_profile().is_some());
assert!(x.gcs_profile().is_none());
assert!(x.mysql_profile().is_none());
assert!(x.bigquery_profile().is_none());
assert!(x.postgresql_profile().is_none());
assert!(x.sql_server_profile().is_none());
assert!(x.salesforce_profile().is_none());
assert!(x.mongodb_profile().is_none());Sourcepub fn gcs_profile(&self) -> Option<&Box<GcsProfile>>
pub fn gcs_profile(&self) -> Option<&Box<GcsProfile>>
The value of profile
if it holds a GcsProfile, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_profile<T: Into<Box<GcsProfile>>>(self, v: T) -> Self
pub fn set_gcs_profile<T: Into<Box<GcsProfile>>>(self, v: T) -> Self
Sets the value of profile
to hold a GcsProfile.
Note that all the setters affecting profile are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::GcsProfile;
let x = ConnectionProfile::new().set_gcs_profile(GcsProfile::default()/* use setters */);
assert!(x.gcs_profile().is_some());
assert!(x.oracle_profile().is_none());
assert!(x.mysql_profile().is_none());
assert!(x.bigquery_profile().is_none());
assert!(x.postgresql_profile().is_none());
assert!(x.sql_server_profile().is_none());
assert!(x.salesforce_profile().is_none());
assert!(x.mongodb_profile().is_none());Sourcepub fn mysql_profile(&self) -> Option<&Box<MysqlProfile>>
pub fn mysql_profile(&self) -> Option<&Box<MysqlProfile>>
The value of profile
if it holds a MysqlProfile, None if the field is not set or
holds a different branch.
Sourcepub fn set_mysql_profile<T: Into<Box<MysqlProfile>>>(self, v: T) -> Self
pub fn set_mysql_profile<T: Into<Box<MysqlProfile>>>(self, v: T) -> Self
Sets the value of profile
to hold a MysqlProfile.
Note that all the setters affecting profile are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::MysqlProfile;
let x = ConnectionProfile::new().set_mysql_profile(MysqlProfile::default()/* use setters */);
assert!(x.mysql_profile().is_some());
assert!(x.oracle_profile().is_none());
assert!(x.gcs_profile().is_none());
assert!(x.bigquery_profile().is_none());
assert!(x.postgresql_profile().is_none());
assert!(x.sql_server_profile().is_none());
assert!(x.salesforce_profile().is_none());
assert!(x.mongodb_profile().is_none());Sourcepub fn bigquery_profile(&self) -> Option<&Box<BigQueryProfile>>
pub fn bigquery_profile(&self) -> Option<&Box<BigQueryProfile>>
The value of profile
if it holds a BigqueryProfile, None if the field is not set or
holds a different branch.
Sourcepub fn set_bigquery_profile<T: Into<Box<BigQueryProfile>>>(self, v: T) -> Self
pub fn set_bigquery_profile<T: Into<Box<BigQueryProfile>>>(self, v: T) -> Self
Sets the value of profile
to hold a BigqueryProfile.
Note that all the setters affecting profile are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::BigQueryProfile;
let x = ConnectionProfile::new().set_bigquery_profile(BigQueryProfile::default()/* use setters */);
assert!(x.bigquery_profile().is_some());
assert!(x.oracle_profile().is_none());
assert!(x.gcs_profile().is_none());
assert!(x.mysql_profile().is_none());
assert!(x.postgresql_profile().is_none());
assert!(x.sql_server_profile().is_none());
assert!(x.salesforce_profile().is_none());
assert!(x.mongodb_profile().is_none());Sourcepub fn postgresql_profile(&self) -> Option<&Box<PostgresqlProfile>>
pub fn postgresql_profile(&self) -> Option<&Box<PostgresqlProfile>>
The value of profile
if it holds a PostgresqlProfile, None if the field is not set or
holds a different branch.
Sourcepub fn set_postgresql_profile<T: Into<Box<PostgresqlProfile>>>(
self,
v: T,
) -> Self
pub fn set_postgresql_profile<T: Into<Box<PostgresqlProfile>>>( self, v: T, ) -> Self
Sets the value of profile
to hold a PostgresqlProfile.
Note that all the setters affecting profile are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::PostgresqlProfile;
let x = ConnectionProfile::new().set_postgresql_profile(PostgresqlProfile::default()/* use setters */);
assert!(x.postgresql_profile().is_some());
assert!(x.oracle_profile().is_none());
assert!(x.gcs_profile().is_none());
assert!(x.mysql_profile().is_none());
assert!(x.bigquery_profile().is_none());
assert!(x.sql_server_profile().is_none());
assert!(x.salesforce_profile().is_none());
assert!(x.mongodb_profile().is_none());Sourcepub fn sql_server_profile(&self) -> Option<&Box<SqlServerProfile>>
pub fn sql_server_profile(&self) -> Option<&Box<SqlServerProfile>>
The value of profile
if it holds a SqlServerProfile, None if the field is not set or
holds a different branch.
Sourcepub fn set_sql_server_profile<T: Into<Box<SqlServerProfile>>>(
self,
v: T,
) -> Self
pub fn set_sql_server_profile<T: Into<Box<SqlServerProfile>>>( self, v: T, ) -> Self
Sets the value of profile
to hold a SqlServerProfile.
Note that all the setters affecting profile are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::SqlServerProfile;
let x = ConnectionProfile::new().set_sql_server_profile(SqlServerProfile::default()/* use setters */);
assert!(x.sql_server_profile().is_some());
assert!(x.oracle_profile().is_none());
assert!(x.gcs_profile().is_none());
assert!(x.mysql_profile().is_none());
assert!(x.bigquery_profile().is_none());
assert!(x.postgresql_profile().is_none());
assert!(x.salesforce_profile().is_none());
assert!(x.mongodb_profile().is_none());Sourcepub fn salesforce_profile(&self) -> Option<&Box<SalesforceProfile>>
pub fn salesforce_profile(&self) -> Option<&Box<SalesforceProfile>>
The value of profile
if it holds a SalesforceProfile, None if the field is not set or
holds a different branch.
Sourcepub fn set_salesforce_profile<T: Into<Box<SalesforceProfile>>>(
self,
v: T,
) -> Self
pub fn set_salesforce_profile<T: Into<Box<SalesforceProfile>>>( self, v: T, ) -> Self
Sets the value of profile
to hold a SalesforceProfile.
Note that all the setters affecting profile are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::SalesforceProfile;
let x = ConnectionProfile::new().set_salesforce_profile(SalesforceProfile::default()/* use setters */);
assert!(x.salesforce_profile().is_some());
assert!(x.oracle_profile().is_none());
assert!(x.gcs_profile().is_none());
assert!(x.mysql_profile().is_none());
assert!(x.bigquery_profile().is_none());
assert!(x.postgresql_profile().is_none());
assert!(x.sql_server_profile().is_none());
assert!(x.mongodb_profile().is_none());Sourcepub fn mongodb_profile(&self) -> Option<&Box<MongodbProfile>>
pub fn mongodb_profile(&self) -> Option<&Box<MongodbProfile>>
The value of profile
if it holds a MongodbProfile, None if the field is not set or
holds a different branch.
Sourcepub fn set_mongodb_profile<T: Into<Box<MongodbProfile>>>(self, v: T) -> Self
pub fn set_mongodb_profile<T: Into<Box<MongodbProfile>>>(self, v: T) -> Self
Sets the value of profile
to hold a MongodbProfile.
Note that all the setters affecting profile are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::MongodbProfile;
let x = ConnectionProfile::new().set_mongodb_profile(MongodbProfile::default()/* use setters */);
assert!(x.mongodb_profile().is_some());
assert!(x.oracle_profile().is_none());
assert!(x.gcs_profile().is_none());
assert!(x.mysql_profile().is_none());
assert!(x.bigquery_profile().is_none());
assert!(x.postgresql_profile().is_none());
assert!(x.sql_server_profile().is_none());
assert!(x.salesforce_profile().is_none());Sourcepub fn set_connectivity<T: Into<Option<Connectivity>>>(self, v: T) -> Self
pub fn set_connectivity<T: Into<Option<Connectivity>>>(self, v: T) -> Self
Sets the value of connectivity.
Note that all the setters affecting connectivity are mutually
exclusive.
Example
use google_cloud_datastream_v1::model::StaticServiceIpConnectivity;
let x = ConnectionProfile::new().set_connectivity(Some(
google_cloud_datastream_v1::model::connection_profile::Connectivity::StaticServiceIpConnectivity(StaticServiceIpConnectivity::default().into())));Sourcepub fn static_service_ip_connectivity(
&self,
) -> Option<&Box<StaticServiceIpConnectivity>>
pub fn static_service_ip_connectivity( &self, ) -> Option<&Box<StaticServiceIpConnectivity>>
The value of connectivity
if it holds a StaticServiceIpConnectivity, None if the field is not set or
holds a different branch.
Sourcepub fn set_static_service_ip_connectivity<T: Into<Box<StaticServiceIpConnectivity>>>(
self,
v: T,
) -> Self
pub fn set_static_service_ip_connectivity<T: Into<Box<StaticServiceIpConnectivity>>>( self, v: T, ) -> Self
Sets the value of connectivity
to hold a StaticServiceIpConnectivity.
Note that all the setters affecting connectivity are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::StaticServiceIpConnectivity;
let x = ConnectionProfile::new().set_static_service_ip_connectivity(StaticServiceIpConnectivity::default()/* use setters */);
assert!(x.static_service_ip_connectivity().is_some());
assert!(x.forward_ssh_connectivity().is_none());
assert!(x.private_connectivity().is_none());Sourcepub fn forward_ssh_connectivity(
&self,
) -> Option<&Box<ForwardSshTunnelConnectivity>>
pub fn forward_ssh_connectivity( &self, ) -> Option<&Box<ForwardSshTunnelConnectivity>>
The value of connectivity
if it holds a ForwardSshConnectivity, None if the field is not set or
holds a different branch.
Sourcepub fn set_forward_ssh_connectivity<T: Into<Box<ForwardSshTunnelConnectivity>>>(
self,
v: T,
) -> Self
pub fn set_forward_ssh_connectivity<T: Into<Box<ForwardSshTunnelConnectivity>>>( self, v: T, ) -> Self
Sets the value of connectivity
to hold a ForwardSshConnectivity.
Note that all the setters affecting connectivity are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::ForwardSshTunnelConnectivity;
let x = ConnectionProfile::new().set_forward_ssh_connectivity(ForwardSshTunnelConnectivity::default()/* use setters */);
assert!(x.forward_ssh_connectivity().is_some());
assert!(x.static_service_ip_connectivity().is_none());
assert!(x.private_connectivity().is_none());Sourcepub fn private_connectivity(&self) -> Option<&Box<PrivateConnectivity>>
pub fn private_connectivity(&self) -> Option<&Box<PrivateConnectivity>>
The value of connectivity
if it holds a PrivateConnectivity, None if the field is not set or
holds a different branch.
Sourcepub fn set_private_connectivity<T: Into<Box<PrivateConnectivity>>>(
self,
v: T,
) -> Self
pub fn set_private_connectivity<T: Into<Box<PrivateConnectivity>>>( self, v: T, ) -> Self
Sets the value of connectivity
to hold a PrivateConnectivity.
Note that all the setters affecting connectivity are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::PrivateConnectivity;
let x = ConnectionProfile::new().set_private_connectivity(PrivateConnectivity::default()/* use setters */);
assert!(x.private_connectivity().is_some());
assert!(x.static_service_ip_connectivity().is_none());
assert!(x.forward_ssh_connectivity().is_none());Trait Implementations
Sourceimpl Clone for ConnectionProfile
impl Clone for ConnectionProfile
Sourcefn clone(&self) -> ConnectionProfile
fn clone(&self) -> ConnectionProfile
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ConnectionProfile
impl Debug for ConnectionProfile
Sourceimpl Default for ConnectionProfile
impl Default for ConnectionProfile
Sourcefn default() -> ConnectionProfile
fn default() -> ConnectionProfile
Sourceimpl Message for ConnectionProfile
impl Message for ConnectionProfile
Sourceimpl PartialEq for ConnectionProfile
impl PartialEq for ConnectionProfile
impl StructuralPartialEq for ConnectionProfile