#[non_exhaustive]pub struct CreateConnectionProfileRequest {
pub parent: String,
pub connection_profile_id: String,
pub connection_profile: Option<ConnectionProfile>,
pub request_id: String,
pub validate_only: bool,
pub force: bool,
/* private fields */
}Expand description
Request message for creating a connection profile.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent that owns the collection of ConnectionProfiles.
connection_profile_id: StringRequired. The connection profile identifier.
connection_profile: Option<ConnectionProfile>Required. The connection profile resource to create.
request_id: StringOptional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
validate_only: boolOptional. Only validate the connection profile, but don’t create any resources. The default is false.
force: boolOptional. Create the connection profile without validating it.
Implementations
Sourceimpl CreateConnectionProfileRequest
impl CreateConnectionProfileRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_connection_profile_id<T: Into<String>>(self, v: T) -> Self
pub fn set_connection_profile_id<T: Into<String>>(self, v: T) -> Self
Sets the value of connection_profile_id.
Example
let x = CreateConnectionProfileRequest::new().set_connection_profile_id("example");Sourcepub fn set_connection_profile<T>(self, v: T) -> Selfwhere
T: Into<ConnectionProfile>,
pub fn set_connection_profile<T>(self, v: T) -> Selfwhere
T: Into<ConnectionProfile>,
Sets the value of connection_profile.
Example
use google_cloud_datastream_v1::model::ConnectionProfile;
let x = CreateConnectionProfileRequest::new().set_connection_profile(ConnectionProfile::default()/* use setters */);Sourcepub fn set_or_clear_connection_profile<T>(self, v: Option<T>) -> Selfwhere
T: Into<ConnectionProfile>,
pub fn set_or_clear_connection_profile<T>(self, v: Option<T>) -> Selfwhere
T: Into<ConnectionProfile>,
Sets or clears the value of connection_profile.
Example
use google_cloud_datastream_v1::model::ConnectionProfile;
let x = CreateConnectionProfileRequest::new().set_or_clear_connection_profile(Some(ConnectionProfile::default()/* use setters */));
let x = CreateConnectionProfileRequest::new().set_or_clear_connection_profile(None::<ConnectionProfile>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateConnectionProfileRequest::new().set_request_id("example");Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = CreateConnectionProfileRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for CreateConnectionProfileRequest
impl Clone for CreateConnectionProfileRequest
Sourcefn clone(&self) -> CreateConnectionProfileRequest
fn clone(&self) -> CreateConnectionProfileRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateConnectionProfileRequest
impl Default for CreateConnectionProfileRequest
Sourcefn default() -> CreateConnectionProfileRequest
fn default() -> CreateConnectionProfileRequest
impl StructuralPartialEq for CreateConnectionProfileRequest