#[non_exhaustive]pub struct DestinationConfig {
pub destination_connection_profile: String,
pub destination_stream_config: Option<DestinationStreamConfig>,
/* private fields */
}Expand description
The configuration of the stream destination.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination_connection_profile: StringRequired. Destination connection profile resource.
Format: projects/{project}/locations/{location}/connectionProfiles/{name}
destination_stream_config: Option<DestinationStreamConfig>Stream configuration that is specific to the data destination type.
Implementations
Sourceimpl DestinationConfig
impl DestinationConfig
Sourcepub fn set_destination_connection_profile<T: Into<String>>(self, v: T) -> Self
pub fn set_destination_connection_profile<T: Into<String>>(self, v: T) -> Self
Sets the value of destination_connection_profile.
Example
let x = DestinationConfig::new().set_destination_connection_profile(format!("projects/{project_id}/locations/{location_id}/connectionProfiles/{connection_profile_id}"));Sourcepub fn set_destination_stream_config<T: Into<Option<DestinationStreamConfig>>>(
self,
v: T,
) -> Self
pub fn set_destination_stream_config<T: Into<Option<DestinationStreamConfig>>>( self, v: T, ) -> Self
Sets the value of destination_stream_config.
Note that all the setters affecting destination_stream_config are mutually
exclusive.
Example
use google_cloud_datastream_v1::model::GcsDestinationConfig;
let x = DestinationConfig::new().set_destination_stream_config(Some(
google_cloud_datastream_v1::model::destination_config::DestinationStreamConfig::GcsDestinationConfig(GcsDestinationConfig::default().into())));Sourcepub fn gcs_destination_config(&self) -> Option<&Box<GcsDestinationConfig>>
pub fn gcs_destination_config(&self) -> Option<&Box<GcsDestinationConfig>>
The value of destination_stream_config
if it holds a GcsDestinationConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_destination_config<T: Into<Box<GcsDestinationConfig>>>(
self,
v: T,
) -> Self
pub fn set_gcs_destination_config<T: Into<Box<GcsDestinationConfig>>>( self, v: T, ) -> Self
Sets the value of destination_stream_config
to hold a GcsDestinationConfig.
Note that all the setters affecting destination_stream_config are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::GcsDestinationConfig;
let x = DestinationConfig::new().set_gcs_destination_config(GcsDestinationConfig::default()/* use setters */);
assert!(x.gcs_destination_config().is_some());
assert!(x.bigquery_destination_config().is_none());Sourcepub fn bigquery_destination_config(
&self,
) -> Option<&Box<BigQueryDestinationConfig>>
pub fn bigquery_destination_config( &self, ) -> Option<&Box<BigQueryDestinationConfig>>
The value of destination_stream_config
if it holds a BigqueryDestinationConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_bigquery_destination_config<T: Into<Box<BigQueryDestinationConfig>>>(
self,
v: T,
) -> Self
pub fn set_bigquery_destination_config<T: Into<Box<BigQueryDestinationConfig>>>( self, v: T, ) -> Self
Sets the value of destination_stream_config
to hold a BigqueryDestinationConfig.
Note that all the setters affecting destination_stream_config are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::BigQueryDestinationConfig;
let x = DestinationConfig::new().set_bigquery_destination_config(BigQueryDestinationConfig::default()/* use setters */);
assert!(x.bigquery_destination_config().is_some());
assert!(x.gcs_destination_config().is_none());Trait Implementations
Sourceimpl Clone for DestinationConfig
impl Clone for DestinationConfig
Sourcefn clone(&self) -> DestinationConfig
fn clone(&self) -> DestinationConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DestinationConfig
impl Debug for DestinationConfig
Sourceimpl Default for DestinationConfig
impl Default for DestinationConfig
Sourcefn default() -> DestinationConfig
fn default() -> DestinationConfig
Sourceimpl Message for DestinationConfig
impl Message for DestinationConfig
Sourceimpl PartialEq for DestinationConfig
impl PartialEq for DestinationConfig
impl StructuralPartialEq for DestinationConfig