#[non_exhaustive]pub struct DiscoverConnectionProfileResponse {
pub data_object: Option<DataObject>,
/* private fields */
}Expand description
Response from a discover request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_object: Option<DataObject>The data object that has been enriched by the discover API call.
Implementations
Sourceimpl DiscoverConnectionProfileResponse
impl DiscoverConnectionProfileResponse
Sourcepub fn set_data_object<T: Into<Option<DataObject>>>(self, v: T) -> Self
pub fn set_data_object<T: Into<Option<DataObject>>>(self, v: T) -> Self
Sets the value of data_object.
Note that all the setters affecting data_object are mutually
exclusive.
Example
use google_cloud_datastream_v1::model::OracleRdbms;
let x = DiscoverConnectionProfileResponse::new().set_data_object(Some(
google_cloud_datastream_v1::model::discover_connection_profile_response::DataObject::OracleRdbms(OracleRdbms::default().into())));Sourcepub fn oracle_rdbms(&self) -> Option<&Box<OracleRdbms>>
pub fn oracle_rdbms(&self) -> Option<&Box<OracleRdbms>>
The value of data_object
if it holds a OracleRdbms, None if the field is not set or
holds a different branch.
Sourcepub fn set_oracle_rdbms<T: Into<Box<OracleRdbms>>>(self, v: T) -> Self
pub fn set_oracle_rdbms<T: Into<Box<OracleRdbms>>>(self, v: T) -> Self
Sets the value of data_object
to hold a OracleRdbms.
Note that all the setters affecting data_object are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::OracleRdbms;
let x = DiscoverConnectionProfileResponse::new().set_oracle_rdbms(OracleRdbms::default()/* use setters */);
assert!(x.oracle_rdbms().is_some());
assert!(x.mysql_rdbms().is_none());
assert!(x.postgresql_rdbms().is_none());
assert!(x.sql_server_rdbms().is_none());
assert!(x.salesforce_org().is_none());
assert!(x.mongodb_cluster().is_none());Sourcepub fn mysql_rdbms(&self) -> Option<&Box<MysqlRdbms>>
pub fn mysql_rdbms(&self) -> Option<&Box<MysqlRdbms>>
The value of data_object
if it holds a MysqlRdbms, None if the field is not set or
holds a different branch.
Sourcepub fn set_mysql_rdbms<T: Into<Box<MysqlRdbms>>>(self, v: T) -> Self
pub fn set_mysql_rdbms<T: Into<Box<MysqlRdbms>>>(self, v: T) -> Self
Sets the value of data_object
to hold a MysqlRdbms.
Note that all the setters affecting data_object are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::MysqlRdbms;
let x = DiscoverConnectionProfileResponse::new().set_mysql_rdbms(MysqlRdbms::default()/* use setters */);
assert!(x.mysql_rdbms().is_some());
assert!(x.oracle_rdbms().is_none());
assert!(x.postgresql_rdbms().is_none());
assert!(x.sql_server_rdbms().is_none());
assert!(x.salesforce_org().is_none());
assert!(x.mongodb_cluster().is_none());Sourcepub fn postgresql_rdbms(&self) -> Option<&Box<PostgresqlRdbms>>
pub fn postgresql_rdbms(&self) -> Option<&Box<PostgresqlRdbms>>
The value of data_object
if it holds a PostgresqlRdbms, None if the field is not set or
holds a different branch.
Sourcepub fn set_postgresql_rdbms<T: Into<Box<PostgresqlRdbms>>>(self, v: T) -> Self
pub fn set_postgresql_rdbms<T: Into<Box<PostgresqlRdbms>>>(self, v: T) -> Self
Sets the value of data_object
to hold a PostgresqlRdbms.
Note that all the setters affecting data_object are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::PostgresqlRdbms;
let x = DiscoverConnectionProfileResponse::new().set_postgresql_rdbms(PostgresqlRdbms::default()/* use setters */);
assert!(x.postgresql_rdbms().is_some());
assert!(x.oracle_rdbms().is_none());
assert!(x.mysql_rdbms().is_none());
assert!(x.sql_server_rdbms().is_none());
assert!(x.salesforce_org().is_none());
assert!(x.mongodb_cluster().is_none());Sourcepub fn sql_server_rdbms(&self) -> Option<&Box<SqlServerRdbms>>
pub fn sql_server_rdbms(&self) -> Option<&Box<SqlServerRdbms>>
The value of data_object
if it holds a SqlServerRdbms, None if the field is not set or
holds a different branch.
Sourcepub fn set_sql_server_rdbms<T: Into<Box<SqlServerRdbms>>>(self, v: T) -> Self
pub fn set_sql_server_rdbms<T: Into<Box<SqlServerRdbms>>>(self, v: T) -> Self
Sets the value of data_object
to hold a SqlServerRdbms.
Note that all the setters affecting data_object are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::SqlServerRdbms;
let x = DiscoverConnectionProfileResponse::new().set_sql_server_rdbms(SqlServerRdbms::default()/* use setters */);
assert!(x.sql_server_rdbms().is_some());
assert!(x.oracle_rdbms().is_none());
assert!(x.mysql_rdbms().is_none());
assert!(x.postgresql_rdbms().is_none());
assert!(x.salesforce_org().is_none());
assert!(x.mongodb_cluster().is_none());Sourcepub fn salesforce_org(&self) -> Option<&Box<SalesforceOrg>>
pub fn salesforce_org(&self) -> Option<&Box<SalesforceOrg>>
The value of data_object
if it holds a SalesforceOrg, None if the field is not set or
holds a different branch.
Sourcepub fn set_salesforce_org<T: Into<Box<SalesforceOrg>>>(self, v: T) -> Self
pub fn set_salesforce_org<T: Into<Box<SalesforceOrg>>>(self, v: T) -> Self
Sets the value of data_object
to hold a SalesforceOrg.
Note that all the setters affecting data_object are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::SalesforceOrg;
let x = DiscoverConnectionProfileResponse::new().set_salesforce_org(SalesforceOrg::default()/* use setters */);
assert!(x.salesforce_org().is_some());
assert!(x.oracle_rdbms().is_none());
assert!(x.mysql_rdbms().is_none());
assert!(x.postgresql_rdbms().is_none());
assert!(x.sql_server_rdbms().is_none());
assert!(x.mongodb_cluster().is_none());Sourcepub fn mongodb_cluster(&self) -> Option<&Box<MongodbCluster>>
pub fn mongodb_cluster(&self) -> Option<&Box<MongodbCluster>>
The value of data_object
if it holds a MongodbCluster, None if the field is not set or
holds a different branch.
Sourcepub fn set_mongodb_cluster<T: Into<Box<MongodbCluster>>>(self, v: T) -> Self
pub fn set_mongodb_cluster<T: Into<Box<MongodbCluster>>>(self, v: T) -> Self
Sets the value of data_object
to hold a MongodbCluster.
Note that all the setters affecting data_object are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::MongodbCluster;
let x = DiscoverConnectionProfileResponse::new().set_mongodb_cluster(MongodbCluster::default()/* use setters */);
assert!(x.mongodb_cluster().is_some());
assert!(x.oracle_rdbms().is_none());
assert!(x.mysql_rdbms().is_none());
assert!(x.postgresql_rdbms().is_none());
assert!(x.sql_server_rdbms().is_none());
assert!(x.salesforce_org().is_none());Trait Implementations
Sourceimpl Clone for DiscoverConnectionProfileResponse
impl Clone for DiscoverConnectionProfileResponse
Sourcefn clone(&self) -> DiscoverConnectionProfileResponse
fn clone(&self) -> DiscoverConnectionProfileResponse
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for DiscoverConnectionProfileResponse
impl Default for DiscoverConnectionProfileResponse
Sourcefn default() -> DiscoverConnectionProfileResponse
fn default() -> DiscoverConnectionProfileResponse
impl StructuralPartialEq for DiscoverConnectionProfileResponse