#[non_exhaustive]pub struct OracleProfile {
pub hostname: String,
pub port: i32,
pub username: String,
pub password: String,
pub database_service: String,
pub connection_attributes: HashMap<String, String>,
pub oracle_ssl_config: Option<OracleSslConfig>,
pub oracle_asm_config: Option<OracleAsmConfig>,
pub secret_manager_stored_password: String,
/* private fields */
}Expand description
Oracle database profile.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.hostname: StringRequired. Hostname for the Oracle connection.
port: i32Port for the Oracle connection, default value is 1521.
username: StringRequired. Username for the Oracle connection.
password: StringOptional. Password for the Oracle connection. Mutually exclusive with the
secret_manager_stored_password field.
database_service: StringRequired. Database for the Oracle connection.
connection_attributes: HashMap<String, String>Connection string attributes
oracle_ssl_config: Option<OracleSslConfig>Optional. SSL configuration for the Oracle connection.
oracle_asm_config: Option<OracleAsmConfig>Optional. Configuration for Oracle ASM connection.
secret_manager_stored_password: StringOptional. A reference to a Secret Manager resource name storing the Oracle
connection password. Mutually exclusive with the password field.
Implementations
Sourceimpl OracleProfile
impl OracleProfile
Sourcepub fn set_hostname<T: Into<String>>(self, v: T) -> Self
pub fn set_hostname<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_username<T: Into<String>>(self, v: T) -> Self
pub fn set_username<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_password<T: Into<String>>(self, v: T) -> Self
pub fn set_password<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_database_service<T: Into<String>>(self, v: T) -> Self
pub fn set_database_service<T: Into<String>>(self, v: T) -> Self
Sets the value of database_service.
Example
let x = OracleProfile::new().set_database_service("example");Sourcepub fn set_connection_attributes<T, K, V>(self, v: T) -> Self
pub fn set_connection_attributes<T, K, V>(self, v: T) -> Self
Sets the value of connection_attributes.
Example
let x = OracleProfile::new().set_connection_attributes([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_oracle_ssl_config<T>(self, v: T) -> Selfwhere
T: Into<OracleSslConfig>,
pub fn set_oracle_ssl_config<T>(self, v: T) -> Selfwhere
T: Into<OracleSslConfig>,
Sets the value of oracle_ssl_config.
Example
use google_cloud_datastream_v1::model::OracleSslConfig;
let x = OracleProfile::new().set_oracle_ssl_config(OracleSslConfig::default()/* use setters */);Sourcepub fn set_or_clear_oracle_ssl_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OracleSslConfig>,
pub fn set_or_clear_oracle_ssl_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OracleSslConfig>,
Sets or clears the value of oracle_ssl_config.
Example
use google_cloud_datastream_v1::model::OracleSslConfig;
let x = OracleProfile::new().set_or_clear_oracle_ssl_config(Some(OracleSslConfig::default()/* use setters */));
let x = OracleProfile::new().set_or_clear_oracle_ssl_config(None::<OracleSslConfig>);Sourcepub fn set_oracle_asm_config<T>(self, v: T) -> Selfwhere
T: Into<OracleAsmConfig>,
pub fn set_oracle_asm_config<T>(self, v: T) -> Selfwhere
T: Into<OracleAsmConfig>,
Sets the value of oracle_asm_config.
Example
use google_cloud_datastream_v1::model::OracleAsmConfig;
let x = OracleProfile::new().set_oracle_asm_config(OracleAsmConfig::default()/* use setters */);Sourcepub fn set_or_clear_oracle_asm_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OracleAsmConfig>,
pub fn set_or_clear_oracle_asm_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OracleAsmConfig>,
Sets or clears the value of oracle_asm_config.
Example
use google_cloud_datastream_v1::model::OracleAsmConfig;
let x = OracleProfile::new().set_or_clear_oracle_asm_config(Some(OracleAsmConfig::default()/* use setters */));
let x = OracleProfile::new().set_or_clear_oracle_asm_config(None::<OracleAsmConfig>);Sourcepub fn set_secret_manager_stored_password<T: Into<String>>(self, v: T) -> Self
pub fn set_secret_manager_stored_password<T: Into<String>>(self, v: T) -> Self
Sets the value of secret_manager_stored_password.
Example
let x = OracleProfile::new().set_secret_manager_stored_password("example");Trait Implementations
Sourceimpl Clone for OracleProfile
impl Clone for OracleProfile
Sourcefn clone(&self) -> OracleProfile
fn clone(&self) -> OracleProfile
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for OracleProfile
impl Debug for OracleProfile
Sourceimpl Default for OracleProfile
impl Default for OracleProfile
Sourcefn default() -> OracleProfile
fn default() -> OracleProfile
Sourceimpl Message for OracleProfile
impl Message for OracleProfile
Sourceimpl PartialEq for OracleProfile
impl PartialEq for OracleProfile
impl StructuralPartialEq for OracleProfile