#[non_exhaustive]pub struct OracleSourceConfig {
pub include_objects: Option<OracleRdbms>,
pub exclude_objects: Option<OracleRdbms>,
pub max_concurrent_cdc_tasks: i32,
pub max_concurrent_backfill_tasks: i32,
pub large_objects_handling: Option<LargeObjectsHandling>,
pub cdc_method: Option<CdcMethod>,
/* private fields */
}Expand description
Oracle data source configuration
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.include_objects: Option<OracleRdbms>Oracle objects to include in the stream.
exclude_objects: Option<OracleRdbms>Oracle objects to exclude from the stream.
max_concurrent_cdc_tasks: i32Maximum number of concurrent CDC tasks. The number should be non-negative. If not set (or set to 0), the system’s default value is used.
max_concurrent_backfill_tasks: i32Maximum number of concurrent backfill tasks. The number should be non-negative. If not set (or set to 0), the system’s default value is used.
large_objects_handling: Option<LargeObjectsHandling>The configuration for handle Oracle large objects.
cdc_method: Option<CdcMethod>Configuration to select the CDC method.
Implementations
Sourceimpl OracleSourceConfig
impl OracleSourceConfig
Sourcepub fn set_include_objects<T>(self, v: T) -> Selfwhere
T: Into<OracleRdbms>,
pub fn set_include_objects<T>(self, v: T) -> Selfwhere
T: Into<OracleRdbms>,
Sets the value of include_objects.
Example
use google_cloud_datastream_v1::model::OracleRdbms;
let x = OracleSourceConfig::new().set_include_objects(OracleRdbms::default()/* use setters */);Sourcepub fn set_or_clear_include_objects<T>(self, v: Option<T>) -> Selfwhere
T: Into<OracleRdbms>,
pub fn set_or_clear_include_objects<T>(self, v: Option<T>) -> Selfwhere
T: Into<OracleRdbms>,
Sets or clears the value of include_objects.
Example
use google_cloud_datastream_v1::model::OracleRdbms;
let x = OracleSourceConfig::new().set_or_clear_include_objects(Some(OracleRdbms::default()/* use setters */));
let x = OracleSourceConfig::new().set_or_clear_include_objects(None::<OracleRdbms>);Sourcepub fn set_exclude_objects<T>(self, v: T) -> Selfwhere
T: Into<OracleRdbms>,
pub fn set_exclude_objects<T>(self, v: T) -> Selfwhere
T: Into<OracleRdbms>,
Sets the value of exclude_objects.
Example
use google_cloud_datastream_v1::model::OracleRdbms;
let x = OracleSourceConfig::new().set_exclude_objects(OracleRdbms::default()/* use setters */);Sourcepub fn set_or_clear_exclude_objects<T>(self, v: Option<T>) -> Selfwhere
T: Into<OracleRdbms>,
pub fn set_or_clear_exclude_objects<T>(self, v: Option<T>) -> Selfwhere
T: Into<OracleRdbms>,
Sets or clears the value of exclude_objects.
Example
use google_cloud_datastream_v1::model::OracleRdbms;
let x = OracleSourceConfig::new().set_or_clear_exclude_objects(Some(OracleRdbms::default()/* use setters */));
let x = OracleSourceConfig::new().set_or_clear_exclude_objects(None::<OracleRdbms>);Sourcepub fn set_max_concurrent_cdc_tasks<T: Into<i32>>(self, v: T) -> Self
pub fn set_max_concurrent_cdc_tasks<T: Into<i32>>(self, v: T) -> Self
Sets the value of max_concurrent_cdc_tasks.
Example
let x = OracleSourceConfig::new().set_max_concurrent_cdc_tasks(42);Sourcepub fn set_max_concurrent_backfill_tasks<T: Into<i32>>(self, v: T) -> Self
pub fn set_max_concurrent_backfill_tasks<T: Into<i32>>(self, v: T) -> Self
Sets the value of max_concurrent_backfill_tasks.
Example
let x = OracleSourceConfig::new().set_max_concurrent_backfill_tasks(42);Sourcepub fn set_large_objects_handling<T: Into<Option<LargeObjectsHandling>>>(
self,
v: T,
) -> Self
pub fn set_large_objects_handling<T: Into<Option<LargeObjectsHandling>>>( self, v: T, ) -> Self
Sets the value of large_objects_handling.
Note that all the setters affecting large_objects_handling are mutually
exclusive.
Example
use google_cloud_datastream_v1::model::oracle_source_config::DropLargeObjects;
let x = OracleSourceConfig::new().set_large_objects_handling(Some(
google_cloud_datastream_v1::model::oracle_source_config::LargeObjectsHandling::DropLargeObjects(DropLargeObjects::default().into())));Sourcepub fn drop_large_objects(&self) -> Option<&Box<DropLargeObjects>>
pub fn drop_large_objects(&self) -> Option<&Box<DropLargeObjects>>
The value of large_objects_handling
if it holds a DropLargeObjects, None if the field is not set or
holds a different branch.
Sourcepub fn set_drop_large_objects<T: Into<Box<DropLargeObjects>>>(
self,
v: T,
) -> Self
pub fn set_drop_large_objects<T: Into<Box<DropLargeObjects>>>( self, v: T, ) -> Self
Sets the value of large_objects_handling
to hold a DropLargeObjects.
Note that all the setters affecting large_objects_handling are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::oracle_source_config::DropLargeObjects;
let x = OracleSourceConfig::new().set_drop_large_objects(DropLargeObjects::default()/* use setters */);
assert!(x.drop_large_objects().is_some());
assert!(x.stream_large_objects().is_none());Sourcepub fn stream_large_objects(&self) -> Option<&Box<StreamLargeObjects>>
pub fn stream_large_objects(&self) -> Option<&Box<StreamLargeObjects>>
The value of large_objects_handling
if it holds a StreamLargeObjects, None if the field is not set or
holds a different branch.
Sourcepub fn set_stream_large_objects<T: Into<Box<StreamLargeObjects>>>(
self,
v: T,
) -> Self
pub fn set_stream_large_objects<T: Into<Box<StreamLargeObjects>>>( self, v: T, ) -> Self
Sets the value of large_objects_handling
to hold a StreamLargeObjects.
Note that all the setters affecting large_objects_handling are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::oracle_source_config::StreamLargeObjects;
let x = OracleSourceConfig::new().set_stream_large_objects(StreamLargeObjects::default()/* use setters */);
assert!(x.stream_large_objects().is_some());
assert!(x.drop_large_objects().is_none());Sourcepub fn set_cdc_method<T: Into<Option<CdcMethod>>>(self, v: T) -> Self
pub fn set_cdc_method<T: Into<Option<CdcMethod>>>(self, v: T) -> Self
Sets the value of cdc_method.
Note that all the setters affecting cdc_method are mutually
exclusive.
Example
use google_cloud_datastream_v1::model::oracle_source_config::LogMiner;
let x = OracleSourceConfig::new().set_cdc_method(Some(
google_cloud_datastream_v1::model::oracle_source_config::CdcMethod::LogMiner(LogMiner::default().into())));Sourcepub fn log_miner(&self) -> Option<&Box<LogMiner>>
pub fn log_miner(&self) -> Option<&Box<LogMiner>>
The value of cdc_method
if it holds a LogMiner, None if the field is not set or
holds a different branch.
Sourcepub fn set_log_miner<T: Into<Box<LogMiner>>>(self, v: T) -> Self
pub fn set_log_miner<T: Into<Box<LogMiner>>>(self, v: T) -> Self
Sets the value of cdc_method
to hold a LogMiner.
Note that all the setters affecting cdc_method are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::oracle_source_config::LogMiner;
let x = OracleSourceConfig::new().set_log_miner(LogMiner::default()/* use setters */);
assert!(x.log_miner().is_some());
assert!(x.binary_log_parser().is_none());Sourcepub fn binary_log_parser(&self) -> Option<&Box<BinaryLogParser>>
pub fn binary_log_parser(&self) -> Option<&Box<BinaryLogParser>>
The value of cdc_method
if it holds a BinaryLogParser, None if the field is not set or
holds a different branch.
Sourcepub fn set_binary_log_parser<T: Into<Box<BinaryLogParser>>>(self, v: T) -> Self
pub fn set_binary_log_parser<T: Into<Box<BinaryLogParser>>>(self, v: T) -> Self
Sets the value of cdc_method
to hold a BinaryLogParser.
Note that all the setters affecting cdc_method are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::oracle_source_config::BinaryLogParser;
let x = OracleSourceConfig::new().set_binary_log_parser(BinaryLogParser::default()/* use setters */);
assert!(x.binary_log_parser().is_some());
assert!(x.log_miner().is_none());Trait Implementations
Sourceimpl Clone for OracleSourceConfig
impl Clone for OracleSourceConfig
Sourcefn clone(&self) -> OracleSourceConfig
fn clone(&self) -> OracleSourceConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for OracleSourceConfig
impl Debug for OracleSourceConfig
Sourceimpl Default for OracleSourceConfig
impl Default for OracleSourceConfig
Sourcefn default() -> OracleSourceConfig
fn default() -> OracleSourceConfig
Sourceimpl Message for OracleSourceConfig
impl Message for OracleSourceConfig
Sourceimpl PartialEq for OracleSourceConfig
impl PartialEq for OracleSourceConfig
impl StructuralPartialEq for OracleSourceConfig