#[non_exhaustive]pub struct PostgresqlProfile {
pub hostname: String,
pub port: i32,
pub username: String,
pub password: String,
pub database: String,
pub secret_manager_stored_password: String,
pub ssl_config: Option<PostgresqlSslConfig>,
/* private fields */
}Expand description
PostgreSQL database profile.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.hostname: StringRequired. Hostname for the PostgreSQL connection.
port: i32Port for the PostgreSQL connection, default value is 5432.
username: StringRequired. Username for the PostgreSQL connection.
password: StringOptional. Password for the PostgreSQL connection. Mutually exclusive with
the secret_manager_stored_password field.
database: StringRequired. Database for the PostgreSQL connection.
secret_manager_stored_password: StringOptional. A reference to a Secret Manager resource name storing the
PostgreSQL connection password. Mutually exclusive with the password
field.
ssl_config: Option<PostgresqlSslConfig>Optional. SSL configuration for the PostgreSQL connection.
In case PostgresqlSslConfig is not set, the connection will use the default
SSL mode, which is prefer (i.e. this mode will only use encryption if
enabled from database side, otherwise will use unencrypted communication)
Implementations
Sourceimpl PostgresqlProfile
impl PostgresqlProfile
Sourcepub fn set_hostname<T: Into<String>>(self, v: T) -> Self
pub fn set_hostname<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_username<T: Into<String>>(self, v: T) -> Self
pub fn set_username<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_password<T: Into<String>>(self, v: T) -> Self
pub fn set_password<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_database<T: Into<String>>(self, v: T) -> Self
pub fn set_database<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_secret_manager_stored_password<T: Into<String>>(self, v: T) -> Self
pub fn set_secret_manager_stored_password<T: Into<String>>(self, v: T) -> Self
Sets the value of secret_manager_stored_password.
Example
let x = PostgresqlProfile::new().set_secret_manager_stored_password("example");Sourcepub fn set_ssl_config<T>(self, v: T) -> Selfwhere
T: Into<PostgresqlSslConfig>,
pub fn set_ssl_config<T>(self, v: T) -> Selfwhere
T: Into<PostgresqlSslConfig>,
Sets the value of ssl_config.
Example
use google_cloud_datastream_v1::model::PostgresqlSslConfig;
let x = PostgresqlProfile::new().set_ssl_config(PostgresqlSslConfig::default()/* use setters */);Sourcepub fn set_or_clear_ssl_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PostgresqlSslConfig>,
pub fn set_or_clear_ssl_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PostgresqlSslConfig>,
Sets or clears the value of ssl_config.
Example
use google_cloud_datastream_v1::model::PostgresqlSslConfig;
let x = PostgresqlProfile::new().set_or_clear_ssl_config(Some(PostgresqlSslConfig::default()/* use setters */));
let x = PostgresqlProfile::new().set_or_clear_ssl_config(None::<PostgresqlSslConfig>);Trait Implementations
Sourceimpl Clone for PostgresqlProfile
impl Clone for PostgresqlProfile
Sourcefn clone(&self) -> PostgresqlProfile
fn clone(&self) -> PostgresqlProfile
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PostgresqlProfile
impl Debug for PostgresqlProfile
Sourceimpl Default for PostgresqlProfile
impl Default for PostgresqlProfile
Sourcefn default() -> PostgresqlProfile
fn default() -> PostgresqlProfile
Sourceimpl Message for PostgresqlProfile
impl Message for PostgresqlProfile
Sourceimpl PartialEq for PostgresqlProfile
impl PartialEq for PostgresqlProfile
impl StructuralPartialEq for PostgresqlProfile