#[non_exhaustive]pub struct PrivateConnection {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub display_name: String,
pub state: State,
pub error: Option<Error>,
pub satisfies_pzs: Option<bool>,
pub satisfies_pzi: Option<bool>,
pub vpc_peering_config: Option<VpcPeeringConfig>,
pub psc_interface_config: Option<PscInterfaceConfig>,
/* private fields */
}Expand description
The PrivateConnection resource is used to establish private connectivity between Datastream and a customer’s network.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. Identifier. The resource’s name.
create_time: Option<Timestamp>Output only. The create time of the resource.
update_time: Option<Timestamp>Output only. The update time of the resource.
labels: HashMap<String, String>Labels.
display_name: StringRequired. Display name.
state: StateOutput only. The state of the Private Connection.
error: Option<Error>Output only. In case of error, the details of the error in a user-friendly format.
satisfies_pzs: Option<bool>Output only. Reserved for future use.
satisfies_pzi: Option<bool>Output only. Reserved for future use.
vpc_peering_config: Option<VpcPeeringConfig>VPC Peering Config.
psc_interface_config: Option<PscInterfaceConfig>PSC Interface Config.
Implementations
Sourceimpl PrivateConnection
impl PrivateConnection
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = PrivateConnection::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = PrivateConnection::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = PrivateConnection::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = PrivateConnection::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = PrivateConnection::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = PrivateConnection::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = PrivateConnection::new().set_display_name("example");Sourcepub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
Sourcepub fn set_satisfies_pzs<T>(self, v: T) -> Self
pub fn set_satisfies_pzs<T>(self, v: T) -> Self
Sets the value of satisfies_pzs.
Example
let x = PrivateConnection::new().set_satisfies_pzs(true);Sourcepub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
Sets or clears the value of satisfies_pzs.
Example
let x = PrivateConnection::new().set_or_clear_satisfies_pzs(Some(false));
let x = PrivateConnection::new().set_or_clear_satisfies_pzs(None::<bool>);Sourcepub fn set_satisfies_pzi<T>(self, v: T) -> Self
pub fn set_satisfies_pzi<T>(self, v: T) -> Self
Sets the value of satisfies_pzi.
Example
let x = PrivateConnection::new().set_satisfies_pzi(true);Sourcepub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
Sets or clears the value of satisfies_pzi.
Example
let x = PrivateConnection::new().set_or_clear_satisfies_pzi(Some(false));
let x = PrivateConnection::new().set_or_clear_satisfies_pzi(None::<bool>);Sourcepub fn set_vpc_peering_config<T>(self, v: T) -> Selfwhere
T: Into<VpcPeeringConfig>,
pub fn set_vpc_peering_config<T>(self, v: T) -> Selfwhere
T: Into<VpcPeeringConfig>,
Sets the value of vpc_peering_config.
Example
use google_cloud_datastream_v1::model::VpcPeeringConfig;
let x = PrivateConnection::new().set_vpc_peering_config(VpcPeeringConfig::default()/* use setters */);Sourcepub fn set_or_clear_vpc_peering_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<VpcPeeringConfig>,
pub fn set_or_clear_vpc_peering_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<VpcPeeringConfig>,
Sets or clears the value of vpc_peering_config.
Example
use google_cloud_datastream_v1::model::VpcPeeringConfig;
let x = PrivateConnection::new().set_or_clear_vpc_peering_config(Some(VpcPeeringConfig::default()/* use setters */));
let x = PrivateConnection::new().set_or_clear_vpc_peering_config(None::<VpcPeeringConfig>);Sourcepub fn set_psc_interface_config<T>(self, v: T) -> Selfwhere
T: Into<PscInterfaceConfig>,
pub fn set_psc_interface_config<T>(self, v: T) -> Selfwhere
T: Into<PscInterfaceConfig>,
Sets the value of psc_interface_config.
Example
use google_cloud_datastream_v1::model::PscInterfaceConfig;
let x = PrivateConnection::new().set_psc_interface_config(PscInterfaceConfig::default()/* use setters */);Sourcepub fn set_or_clear_psc_interface_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PscInterfaceConfig>,
pub fn set_or_clear_psc_interface_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PscInterfaceConfig>,
Sets or clears the value of psc_interface_config.
Example
use google_cloud_datastream_v1::model::PscInterfaceConfig;
let x = PrivateConnection::new().set_or_clear_psc_interface_config(Some(PscInterfaceConfig::default()/* use setters */));
let x = PrivateConnection::new().set_or_clear_psc_interface_config(None::<PscInterfaceConfig>);Trait Implementations
Sourceimpl Clone for PrivateConnection
impl Clone for PrivateConnection
Sourcefn clone(&self) -> PrivateConnection
fn clone(&self) -> PrivateConnection
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PrivateConnection
impl Debug for PrivateConnection
Sourceimpl Default for PrivateConnection
impl Default for PrivateConnection
Sourcefn default() -> PrivateConnection
fn default() -> PrivateConnection
Sourceimpl Message for PrivateConnection
impl Message for PrivateConnection
Sourceimpl PartialEq for PrivateConnection
impl PartialEq for PrivateConnection
impl StructuralPartialEq for PrivateConnection