#[non_exhaustive]pub struct SourceObjectIdentifier {
pub source_identifier: Option<SourceIdentifier>,
/* private fields */
}Expand description
Represents an identifier of an object in the data source.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_identifier: Option<SourceIdentifier>The identifier for an object in the data source.
Implementations
Sourceimpl SourceObjectIdentifier
impl SourceObjectIdentifier
Sourcepub fn set_source_identifier<T: Into<Option<SourceIdentifier>>>(
self,
v: T,
) -> Self
pub fn set_source_identifier<T: Into<Option<SourceIdentifier>>>( self, v: T, ) -> Self
Sets the value of source_identifier.
Note that all the setters affecting source_identifier are mutually
exclusive.
Example
use google_cloud_datastream_v1::model::source_object_identifier::OracleObjectIdentifier;
let x = SourceObjectIdentifier::new().set_source_identifier(Some(
google_cloud_datastream_v1::model::source_object_identifier::SourceIdentifier::OracleIdentifier(OracleObjectIdentifier::default().into())));Sourcepub fn oracle_identifier(&self) -> Option<&Box<OracleObjectIdentifier>>
pub fn oracle_identifier(&self) -> Option<&Box<OracleObjectIdentifier>>
The value of source_identifier
if it holds a OracleIdentifier, None if the field is not set or
holds a different branch.
Sourcepub fn set_oracle_identifier<T: Into<Box<OracleObjectIdentifier>>>(
self,
v: T,
) -> Self
pub fn set_oracle_identifier<T: Into<Box<OracleObjectIdentifier>>>( self, v: T, ) -> Self
Sets the value of source_identifier
to hold a OracleIdentifier.
Note that all the setters affecting source_identifier are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::source_object_identifier::OracleObjectIdentifier;
let x = SourceObjectIdentifier::new().set_oracle_identifier(OracleObjectIdentifier::default()/* use setters */);
assert!(x.oracle_identifier().is_some());
assert!(x.mysql_identifier().is_none());
assert!(x.postgresql_identifier().is_none());
assert!(x.sql_server_identifier().is_none());
assert!(x.salesforce_identifier().is_none());
assert!(x.mongodb_identifier().is_none());Sourcepub fn mysql_identifier(&self) -> Option<&Box<MysqlObjectIdentifier>>
pub fn mysql_identifier(&self) -> Option<&Box<MysqlObjectIdentifier>>
The value of source_identifier
if it holds a MysqlIdentifier, None if the field is not set or
holds a different branch.
Sourcepub fn set_mysql_identifier<T: Into<Box<MysqlObjectIdentifier>>>(
self,
v: T,
) -> Self
pub fn set_mysql_identifier<T: Into<Box<MysqlObjectIdentifier>>>( self, v: T, ) -> Self
Sets the value of source_identifier
to hold a MysqlIdentifier.
Note that all the setters affecting source_identifier are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::source_object_identifier::MysqlObjectIdentifier;
let x = SourceObjectIdentifier::new().set_mysql_identifier(MysqlObjectIdentifier::default()/* use setters */);
assert!(x.mysql_identifier().is_some());
assert!(x.oracle_identifier().is_none());
assert!(x.postgresql_identifier().is_none());
assert!(x.sql_server_identifier().is_none());
assert!(x.salesforce_identifier().is_none());
assert!(x.mongodb_identifier().is_none());Sourcepub fn postgresql_identifier(&self) -> Option<&Box<PostgresqlObjectIdentifier>>
pub fn postgresql_identifier(&self) -> Option<&Box<PostgresqlObjectIdentifier>>
The value of source_identifier
if it holds a PostgresqlIdentifier, None if the field is not set or
holds a different branch.
Sourcepub fn set_postgresql_identifier<T: Into<Box<PostgresqlObjectIdentifier>>>(
self,
v: T,
) -> Self
pub fn set_postgresql_identifier<T: Into<Box<PostgresqlObjectIdentifier>>>( self, v: T, ) -> Self
Sets the value of source_identifier
to hold a PostgresqlIdentifier.
Note that all the setters affecting source_identifier are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::source_object_identifier::PostgresqlObjectIdentifier;
let x = SourceObjectIdentifier::new().set_postgresql_identifier(PostgresqlObjectIdentifier::default()/* use setters */);
assert!(x.postgresql_identifier().is_some());
assert!(x.oracle_identifier().is_none());
assert!(x.mysql_identifier().is_none());
assert!(x.sql_server_identifier().is_none());
assert!(x.salesforce_identifier().is_none());
assert!(x.mongodb_identifier().is_none());Sourcepub fn sql_server_identifier(&self) -> Option<&Box<SqlServerObjectIdentifier>>
pub fn sql_server_identifier(&self) -> Option<&Box<SqlServerObjectIdentifier>>
The value of source_identifier
if it holds a SqlServerIdentifier, None if the field is not set or
holds a different branch.
Sourcepub fn set_sql_server_identifier<T: Into<Box<SqlServerObjectIdentifier>>>(
self,
v: T,
) -> Self
pub fn set_sql_server_identifier<T: Into<Box<SqlServerObjectIdentifier>>>( self, v: T, ) -> Self
Sets the value of source_identifier
to hold a SqlServerIdentifier.
Note that all the setters affecting source_identifier are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::source_object_identifier::SqlServerObjectIdentifier;
let x = SourceObjectIdentifier::new().set_sql_server_identifier(SqlServerObjectIdentifier::default()/* use setters */);
assert!(x.sql_server_identifier().is_some());
assert!(x.oracle_identifier().is_none());
assert!(x.mysql_identifier().is_none());
assert!(x.postgresql_identifier().is_none());
assert!(x.salesforce_identifier().is_none());
assert!(x.mongodb_identifier().is_none());Sourcepub fn salesforce_identifier(&self) -> Option<&Box<SalesforceObjectIdentifier>>
pub fn salesforce_identifier(&self) -> Option<&Box<SalesforceObjectIdentifier>>
The value of source_identifier
if it holds a SalesforceIdentifier, None if the field is not set or
holds a different branch.
Sourcepub fn set_salesforce_identifier<T: Into<Box<SalesforceObjectIdentifier>>>(
self,
v: T,
) -> Self
pub fn set_salesforce_identifier<T: Into<Box<SalesforceObjectIdentifier>>>( self, v: T, ) -> Self
Sets the value of source_identifier
to hold a SalesforceIdentifier.
Note that all the setters affecting source_identifier are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::source_object_identifier::SalesforceObjectIdentifier;
let x = SourceObjectIdentifier::new().set_salesforce_identifier(SalesforceObjectIdentifier::default()/* use setters */);
assert!(x.salesforce_identifier().is_some());
assert!(x.oracle_identifier().is_none());
assert!(x.mysql_identifier().is_none());
assert!(x.postgresql_identifier().is_none());
assert!(x.sql_server_identifier().is_none());
assert!(x.mongodb_identifier().is_none());Sourcepub fn mongodb_identifier(&self) -> Option<&Box<MongodbObjectIdentifier>>
pub fn mongodb_identifier(&self) -> Option<&Box<MongodbObjectIdentifier>>
The value of source_identifier
if it holds a MongodbIdentifier, None if the field is not set or
holds a different branch.
Sourcepub fn set_mongodb_identifier<T: Into<Box<MongodbObjectIdentifier>>>(
self,
v: T,
) -> Self
pub fn set_mongodb_identifier<T: Into<Box<MongodbObjectIdentifier>>>( self, v: T, ) -> Self
Sets the value of source_identifier
to hold a MongodbIdentifier.
Note that all the setters affecting source_identifier are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::source_object_identifier::MongodbObjectIdentifier;
let x = SourceObjectIdentifier::new().set_mongodb_identifier(MongodbObjectIdentifier::default()/* use setters */);
assert!(x.mongodb_identifier().is_some());
assert!(x.oracle_identifier().is_none());
assert!(x.mysql_identifier().is_none());
assert!(x.postgresql_identifier().is_none());
assert!(x.sql_server_identifier().is_none());
assert!(x.salesforce_identifier().is_none());Trait Implementations
Sourceimpl Clone for SourceObjectIdentifier
impl Clone for SourceObjectIdentifier
Sourcefn clone(&self) -> SourceObjectIdentifier
fn clone(&self) -> SourceObjectIdentifier
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SourceObjectIdentifier
impl Debug for SourceObjectIdentifier
Sourceimpl Default for SourceObjectIdentifier
impl Default for SourceObjectIdentifier
Sourcefn default() -> SourceObjectIdentifier
fn default() -> SourceObjectIdentifier
Sourceimpl Message for SourceObjectIdentifier
impl Message for SourceObjectIdentifier
Sourceimpl PartialEq for SourceObjectIdentifier
impl PartialEq for SourceObjectIdentifier
impl StructuralPartialEq for SourceObjectIdentifier