#[non_exhaustive]pub struct SqlServerSourceConfig {
pub include_objects: Option<SqlServerRdbms>,
pub exclude_objects: Option<SqlServerRdbms>,
pub max_concurrent_cdc_tasks: i32,
pub max_concurrent_backfill_tasks: i32,
pub cdc_method: Option<CdcMethod>,
/* private fields */
}Expand description
SQLServer data source configuration
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.include_objects: Option<SqlServerRdbms>SQLServer objects to include in the stream.
exclude_objects: Option<SqlServerRdbms>SQLServer objects to exclude from the stream.
max_concurrent_cdc_tasks: i32Max concurrent CDC tasks.
max_concurrent_backfill_tasks: i32Max concurrent backfill tasks.
cdc_method: Option<CdcMethod>Configuration to select the CDC read method for the stream.
Implementations
Sourceimpl SqlServerSourceConfig
impl SqlServerSourceConfig
Sourcepub fn set_include_objects<T>(self, v: T) -> Selfwhere
T: Into<SqlServerRdbms>,
pub fn set_include_objects<T>(self, v: T) -> Selfwhere
T: Into<SqlServerRdbms>,
Sets the value of include_objects.
Example
use google_cloud_datastream_v1::model::SqlServerRdbms;
let x = SqlServerSourceConfig::new().set_include_objects(SqlServerRdbms::default()/* use setters */);Sourcepub fn set_or_clear_include_objects<T>(self, v: Option<T>) -> Selfwhere
T: Into<SqlServerRdbms>,
pub fn set_or_clear_include_objects<T>(self, v: Option<T>) -> Selfwhere
T: Into<SqlServerRdbms>,
Sets or clears the value of include_objects.
Example
use google_cloud_datastream_v1::model::SqlServerRdbms;
let x = SqlServerSourceConfig::new().set_or_clear_include_objects(Some(SqlServerRdbms::default()/* use setters */));
let x = SqlServerSourceConfig::new().set_or_clear_include_objects(None::<SqlServerRdbms>);Sourcepub fn set_exclude_objects<T>(self, v: T) -> Selfwhere
T: Into<SqlServerRdbms>,
pub fn set_exclude_objects<T>(self, v: T) -> Selfwhere
T: Into<SqlServerRdbms>,
Sets the value of exclude_objects.
Example
use google_cloud_datastream_v1::model::SqlServerRdbms;
let x = SqlServerSourceConfig::new().set_exclude_objects(SqlServerRdbms::default()/* use setters */);Sourcepub fn set_or_clear_exclude_objects<T>(self, v: Option<T>) -> Selfwhere
T: Into<SqlServerRdbms>,
pub fn set_or_clear_exclude_objects<T>(self, v: Option<T>) -> Selfwhere
T: Into<SqlServerRdbms>,
Sets or clears the value of exclude_objects.
Example
use google_cloud_datastream_v1::model::SqlServerRdbms;
let x = SqlServerSourceConfig::new().set_or_clear_exclude_objects(Some(SqlServerRdbms::default()/* use setters */));
let x = SqlServerSourceConfig::new().set_or_clear_exclude_objects(None::<SqlServerRdbms>);Sourcepub fn set_max_concurrent_cdc_tasks<T: Into<i32>>(self, v: T) -> Self
pub fn set_max_concurrent_cdc_tasks<T: Into<i32>>(self, v: T) -> Self
Sets the value of max_concurrent_cdc_tasks.
Example
let x = SqlServerSourceConfig::new().set_max_concurrent_cdc_tasks(42);Sourcepub fn set_max_concurrent_backfill_tasks<T: Into<i32>>(self, v: T) -> Self
pub fn set_max_concurrent_backfill_tasks<T: Into<i32>>(self, v: T) -> Self
Sets the value of max_concurrent_backfill_tasks.
Example
let x = SqlServerSourceConfig::new().set_max_concurrent_backfill_tasks(42);Sourcepub fn set_cdc_method<T: Into<Option<CdcMethod>>>(self, v: T) -> Self
pub fn set_cdc_method<T: Into<Option<CdcMethod>>>(self, v: T) -> Self
Sets the value of cdc_method.
Note that all the setters affecting cdc_method are mutually
exclusive.
Example
use google_cloud_datastream_v1::model::SqlServerTransactionLogs;
let x = SqlServerSourceConfig::new().set_cdc_method(Some(
google_cloud_datastream_v1::model::sql_server_source_config::CdcMethod::TransactionLogs(SqlServerTransactionLogs::default().into())));Sourcepub fn transaction_logs(&self) -> Option<&Box<SqlServerTransactionLogs>>
pub fn transaction_logs(&self) -> Option<&Box<SqlServerTransactionLogs>>
The value of cdc_method
if it holds a TransactionLogs, None if the field is not set or
holds a different branch.
Sourcepub fn set_transaction_logs<T: Into<Box<SqlServerTransactionLogs>>>(
self,
v: T,
) -> Self
pub fn set_transaction_logs<T: Into<Box<SqlServerTransactionLogs>>>( self, v: T, ) -> Self
Sets the value of cdc_method
to hold a TransactionLogs.
Note that all the setters affecting cdc_method are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::SqlServerTransactionLogs;
let x = SqlServerSourceConfig::new().set_transaction_logs(SqlServerTransactionLogs::default()/* use setters */);
assert!(x.transaction_logs().is_some());
assert!(x.change_tables().is_none());Sourcepub fn change_tables(&self) -> Option<&Box<SqlServerChangeTables>>
pub fn change_tables(&self) -> Option<&Box<SqlServerChangeTables>>
The value of cdc_method
if it holds a ChangeTables, None if the field is not set or
holds a different branch.
Sourcepub fn set_change_tables<T: Into<Box<SqlServerChangeTables>>>(
self,
v: T,
) -> Self
pub fn set_change_tables<T: Into<Box<SqlServerChangeTables>>>( self, v: T, ) -> Self
Sets the value of cdc_method
to hold a ChangeTables.
Note that all the setters affecting cdc_method are
mutually exclusive.
Example
use google_cloud_datastream_v1::model::SqlServerChangeTables;
let x = SqlServerSourceConfig::new().set_change_tables(SqlServerChangeTables::default()/* use setters */);
assert!(x.change_tables().is_some());
assert!(x.transaction_logs().is_none());Trait Implementations
Sourceimpl Clone for SqlServerSourceConfig
impl Clone for SqlServerSourceConfig
Sourcefn clone(&self) -> SqlServerSourceConfig
fn clone(&self) -> SqlServerSourceConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SqlServerSourceConfig
impl Debug for SqlServerSourceConfig
Sourceimpl Default for SqlServerSourceConfig
impl Default for SqlServerSourceConfig
Sourcefn default() -> SqlServerSourceConfig
fn default() -> SqlServerSourceConfig
Sourceimpl Message for SqlServerSourceConfig
impl Message for SqlServerSourceConfig
Sourceimpl PartialEq for SqlServerSourceConfig
impl PartialEq for SqlServerSourceConfig
impl StructuralPartialEq for SqlServerSourceConfig